Learn R Programming

TukeyGH77 (version 0.1.4)

TukeyGH77-package: Tukey \(g\)-&-\(h\) Distribution

Description

Density, cumulative density, quantile and simulation of the 4-parameter Tukey (1977) \(g\)-&-\(h\) distributions. The quantile-based transformation (Hoaglin 1985) and its reverse transformation, as well as the letter-value based estimates (Hoaglin 1985), are also provided.

Arguments

Value

Returned values of individual functions are documented separately.

Author

Maintainer: Tingting Zhan tingtingzhan@gmail.com

Other contributors:

References

Tukey, J.W. (1977): Modern Techniques in Data Analysis. In: NSF-sponsored Regional Research Conference at Southeastern Massachusetts University, North Dartmouth, MA.

Hoaglin, D.C. (1985): Summarizing shape numerically: The \(g\)-and-\(h\) distributions. Exploring data tables, trends, and shapes, pp. 461–513. John Wiley & Sons, Ltd, New York. tools:::Rd_expr_doi("10.1002/9781118150702.ch11")